/* VzImagination (C) 2018-2019 Stephane Charette <stephanecharette@gmail.com>
 * $Id: TestUtil.cpp 2741 2019-04-09 17:04:20Z stephane $
 */

#include "TestUtil.hpp"
#include <filesystem>


vz::MStr get_test_images_map()
{
	// The string passed in by cmake is semi-colon separated, such as "a.jpg;b.jpg;c.jpg".
	std::stringstream ss(get_image_filenames_from_cmake());

	vz::MStr m;
	std::string filename;
	while (std::getline(ss, filename, ';'))
	{
		std::string name = filename;

		// if we can, remove both the path and the extension from the filename to get a better name

		size_t pos;
		pos = name.rfind('.');
		if (pos != std::string::npos)
		{
			name.erase(pos);
		}
		pos = name.find_last_of("/\\");
		if (pos != std::string::npos)
		{
			name.erase(0, pos + 1);
		}

		m[filename] = name;

		std::cout << m.size() << ": " << filename << " -> " << name << std::endl;
	}

	return m;
}


vz::MStr copy_test_images()
{
	vz::MStr m;

	const std::filesystem::path cwd = std::filesystem::current_path();
	std::cout << "current working directory is " << cwd << std::endl;

	for (const auto & [path, name] : get_test_images_map())
	{
		const std::filesystem::path src = path;
		const std::filesystem::path dst = cwd / src.filename();

		std::cout << "copying test image " << name << " from " << src << " to " << dst << std::endl;
		std::filesystem::copy_file(src, dst, std::filesystem::copy_options::overwrite_existing);

		m[src.filename()] = name;
	}

	return m;
}


vz::MStr test_images()
{
	static vz::MStr m;
	if (m.empty())
	{
		m = copy_test_images();

		std::cout << m.size() << " test images:" << std::endl;
		for (const auto & [path, name] : m)
		{
			std::cout << "-> path=" << path << ", name=" << name << std::endl;
		}
	}

	return m;
}


vz::MStr trivial_test_images()
{
	static vz::MStr m;
	if (m.empty())
	{
		for (const auto & [path, name] : test_images())
		{
			if (name.size() == 1)
			{
				m[path] = name;
			}
		}
	}

	return m;
}


vz::MStr complex_test_images()
{
	static vz::MStr m;
	if (m.empty())
	{
		for (const auto & [path, name] : test_images())
		{
			if (name.size() > 1)
			{
				m[path] = name;
			}
		}
	}

	return m;
}
